@@ -15,27 +15,33 @@ public class Server
 
 	    poa.the_POAManager().activate();
 	    
-	    org.omg.CORBA.Object o = poa.servant_to_reference(new gridImpl());
+	    org.omg.CORBA.Object o = 
+                poa.servant_to_reference( new gridImpl() );
 
 	    if( args.length == 1 ) 
 	    {
 	       	// write the object reference to args[0]
 
-		PrintWriter ps = new PrintWriter(new FileOutputStream(new File( args[0] )));
+		PrintWriter ps = 
+                    new PrintWriter(new FileOutputStream(new File( args[0] )));
 		ps.println( orb.object_to_string( o ) );
 		ps.close();
 	    } 
 	    else
 	    {
-		NamingContextExt nc = NamingContextExtHelper.narrow(orb.resolve_initial_references("NameService"));
+                // use the naming service
+
+		NamingContextExt nc = 
+                    NamingContextExtHelper.narrow(orb.resolve_initial_references("NameService"));
 		nc.bind( nc.to_name("grid.example"), o);
 	    }
+
+            orb.run();
 	} 
 	catch ( Exception e )
 	{
 	    e.printStackTrace();
-	}
-	orb.run();
+	}        
     }
 }
 
